@@ -1,20 +1,20 @@
 /*
-   interpreter.c: file contains read-eval-print loop and
-   supportive functions
+  interpreter.c: file contains read-eval-print loop and
+  supportive functions
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2, or (at
-   your option) any later version.
+  This program is free software; you can redistribute it and/or
+  modify it under the terms of the GNU General Public License as
+  published by the Free Software Foundation; either version 2, or (at
+  your option) any later version.
 
-   This program is distributed in the hope that it will be useful, but
-   WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
+  This program is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */
 
 
 #include <stdio.h>
@@ -41,68 +41,71 @@
 #include "yahoo-backend.h"
 #include <config.h>
 
-char *commands[] = { "?send", "?who", "?add", "?remove", "?reject", "?ignore", 
-		     "?ignorelist", "?unignore", "?help", "?status", 
-		     "?refresh", "?toggle", "?bell", "?eval", "?load",
-		     "?quit", "?conf-start", "?conf-add", "?conf-join",
-		     "?conf-decline", "?conf-end", "?conf-list", "?conf-send", 
-		     "?send-file", FH_ROBOT, NULL
+extern void ext_yahoo_got_buddies (int id, YList * buds);
+extern void ext_yahoo_got_ignore (int id, YList * igns);
+
+char *commands[] = { "/send", "/who", "/add", "/remove", "/reject", "/ignore", 
+		     "/ignorelist", "/unignore", "/help", "/status", 
+		     "/refresh", "/toggle", "/bell", "/eval", "/load",
+		     "/quit", "/conf-start", "/conf-add", "/conf-join",
+		     "/conf-decline", "/conf-end", "/conf-list", "/conf-send", 
+		     "/send-file", FH_ROBOT, NULL
 };
 
 char * autocomplete_buddy_regex =  		
-                /* regex header */
-		"^\\ *\\?("
+/* regex header */
+"^\\ *\\/("
 		
-               /* commands which accept 1st arg as buddy */
-		"send|send\\-file|ignore|unignore|add|remove|reject|color\\-buddy|ping|buzz|forward|vconf\\-start|xmessage|freehoo|"
+/* commands which accept 1st arg as buddy */
+"send|send\\-file|ignore|unignore|add|remove|reject|color\\-buddy|ping|buzz|forward|vconf\\-start|xmessage|freehoo|morse\\-send|"
 		
-		/* commands which accpet 1st arg and beyond as buddies */
-		"(forward|vconf\\-start)\\ +[a-zA-Z0-9_\\-\\ ]*|" 
+/* commands which accpet 1st arg and beyond as buddies */
+"(forward|vconf\\-start)\\ +[a-zA-Z0-9_\\-\\ ]*|" 
 		
-		/* commands which accept 2nd arg and beyond
-                 * as buddies, but first as non buddy.. like
-                 * confroom or virtual buddy (not yet buddy) 
-                 */
-		"(alias|conf\\-start)\\ +[a-zA-Z0-9_\\-\\ ]+|"
+/* commands which accept 2nd arg and beyond
+ * as buddies, but first as non buddy.. like
+ * confroom or virtual buddy (not yet buddy) 
+ */
+"(alias|conf\\-start)\\ +[a-zA-Z0-9_\\-\\ ]+|"
 
-		/* command which accept 2nd arg only as 
-                 * buddy, 1st arg being non buddy, like 
-		 * confroom
-		 */
-		"(conf\\-add)\\ +[a-zA-Z0-9_\\-]+"
+/* command which accept 2nd arg only as 
+ * buddy, 1st arg being non buddy, like 
+ * confroom
+ */
+"(conf\\-add)\\ +[a-zA-Z0-9_\\-]+"
 
-		/* regex footer, possibly along with the 
-		 * half-d00d! at the end */
-		")\\ +[a-zA-Z0-9_\\-]*$" ;
+/* regex footer, possibly along with the 
+ * half-d00d! at the end */
+")\\ +[a-zA-Z0-9_\\-]*$" ;
 
 char * autocomplete_conf_regex = 		
-                /* regex header */
-		"^\\ *\\?("
+/* regex header */
+"^\\ *\\/("
 		
-               /* commands which accept 1st arg as confroom*/
-		"conf\\-add|conf\\-join|conf\\-decline|conf\\-end|conf\\-send"
+/* commands which accept 1st arg as confroom*/
+"conf\\-add|conf\\-join|conf\\-decline|conf\\-end|conf\\-send"
 	
-		/* regex footer, possibly along with the 
-		 * half conf-room*/
-		")\\ +[a-zA-Z0-9_\\-]*$" ;
+/* regex footer, possibly along with the 
+ * half conf-room*/
+")\\ +[a-zA-Z0-9_\\-]*$" ;
 
 char * autocomplete_file_regex = 		
-                /* regex header */
-		"^\\ *\\?("
+/* regex header */
+"^\\ *\\/("
 		
-          /* commands which accept 2nd arg as filename*/
-		"(send\\-file|send\\-newfile)\\ +[a-zA-Z0-9_\\-]+\\ +)|" 
+/* commands which accept 2nd arg as filename*/
+"(send\\-file|send\\-newfile)\\ +[a-zA-Z0-9_\\-]+\\ +)|" 
 
-          /* commands which accept 1st arg as filename*/
-        "load|loadconfig"
+/* commands which accept 1st arg as filename*/
+"load|loadconfig"
 
-		/* regex footer, possibly along with the 
-		 * half filename*/
-		")\\ +[a-zA-Z0-9_\\-\\/\\.]*$" ;
+/* regex footer, possibly along with the 
+ * half filename*/
+")\\ +[a-zA-Z0-9_\\-\\/\\.]*$" ;
 
 char * autocomplete_cmd_regex = 		
-                /* still in first word or no words yet*/
-		"^\\ *\\??[a-zA-Z0-9_\\-]*$" ;
+/* still in first word or no words yet*/
+"^\\ *\\/?[a-zA-Z0-9_\\-]*$" ;
 
 extern YList *conferences;
 
@@ -231,8 +234,8 @@ unregister_command (SCM command)
     {
       tmp_scm = gh_list_ref (dynamic_commands, gh_ulong2scm (dynamic_command_index++));
       dynamic_cmd = gh_scm2newstr (gh_list_ref (tmp_scm,
-						 gh_ulong2scm (0)),
-				    NULL);
+						gh_ulong2scm (0)),
+				   NULL);
       if (dynamic_cmd && strcasecmp (dynamic_cmd, dynamic_command) == 0)
 	{
 	  dynamic_commands = scm_delete (tmp_scm, dynamic_commands);
@@ -272,11 +275,11 @@ command_generator (const char *text, int state)
   static YList *conflist = NULL;
   static struct dict_words *dw;
   static char complete_buddy = 0,
-	      complete_conf = 0,
-	      complete_toggle = 0,
-	      complete_file = 0,
-	      complete_dict = 0,
-              complete_cmd = 0; // flags because regex is expensive
+    complete_conf = 0,
+    complete_toggle = 0,
+    complete_file = 0,
+    complete_dict = 0,
+    complete_cmd = 0; // flags because regex is expensive
 
   if (!state)
     {
@@ -294,71 +297,71 @@ command_generator (const char *text, int state)
       dw = NULL;
      
       rl_line_buffer[rl_point] = '\0'; /* the effect should be such
-					 * that the cursor position
-					 * is at the end of line for
-					 * the auto completion regex
-					 * above (note the $ at end)
-					 */
+					* that the cursor position
+					* is at the end of line for
+					* the auto completion regex
+					* above (note the $ at end)
+					*/
 
       /* check for the d00d's need in the context */
       regcomp(&preg,autocomplete_buddy_regex,REG_EXTENDED|REG_ICASE);
       if (  !regexec(&preg,rl_line_buffer,0,NULL,0))
         {
-            complete_buddy = 1;
+	  complete_buddy = 1;
         }
-       regfree(&preg);
+      regfree(&preg);
 
       /* check for a conf need in the context */
       regcomp(&preg,autocomplete_conf_regex,REG_EXTENDED|REG_ICASE);
       if ( !regexec(&preg,rl_line_buffer,0,NULL,0))
         {
-            complete_conf = 1;
+	  complete_conf = 1;
         }
-       regfree(&preg);
+      regfree(&preg);
 
-       /* check for a file need in the context */
+      /* check for a file need in the context */
       regcomp(&preg,autocomplete_file_regex,REG_EXTENDED|REG_ICASE);
       if ( !regexec(&preg,rl_line_buffer,0,NULL,0))
         {
-            complete_file = 1;
+	  complete_file = 1;
         }
-       regfree(&preg);
+      regfree(&preg);
      
-        /* ?toggle is pardoned for now	*/
-        if (strncmp (rl_line_buffer, "?toggle ", 8) == 0)
+      /* ?toggle is pardoned for now	*/
+      if (strncmp (rl_line_buffer, "/toggle ", 8) == 0)
 	{
-            complete_toggle = 1;
+	  complete_toggle = 1;
 	}
 	
-        regcomp(&preg,autocomplete_cmd_regex,REG_EXTENDED|REG_ICASE);
-        if ( !regexec(&preg,rl_line_buffer,0,NULL,0))
+      regcomp(&preg,autocomplete_cmd_regex,REG_EXTENDED|REG_ICASE);
+      if ( !regexec(&preg,rl_line_buffer,0,NULL,0))
         {
-            complete_conf = 1;
-            complete_cmd = 1;
-            complete_buddy = 1;
+	  complete_conf = 1;
+	  complete_cmd = 1;
+	  complete_buddy = 1;
         }
-        regfree(&preg);
+      regfree(&preg);
         
-	/* if no context available, default to buddy completion */
-	if(!complete_buddy && !complete_cmd && !complete_conf && !complete_cmd && !complete_file && !complete_toggle) 
-        {
-             complete_dict = 1;
-             dw = word_list;
-	     while (dw) {
-                if (!strncmp (dw->word, text, strlen (text)))
-                    break;
-                dw = dw->next;
-	     }
-        }
-
-       rl_line_buffer[rl_point] = curr_char; /* what effect? :-) */
-
-      }
-
-    if(complete_file) 
-	return rl_filename_completion_function(text,state);
-
-    if(complete_buddy) 
+      /* if no context available, default to buddy completion */
+      if(!complete_buddy && !complete_cmd && !complete_conf && !complete_cmd && !complete_file && !complete_toggle) 
+	{
+	  complete_dict = 1;
+	  dw = word_list;
+	  while (dw) {
+	    if (!strncmp (dw->word, text, strlen (text)))
+	      break;
+	    dw = dw->next;
+	  }
+	}
+	
+      rl_line_buffer[rl_point] = curr_char; /* what effect? :-) */
+	
+    }
+  
+  if(complete_file) 
+    return rl_filename_completion_function(text,state);
+  
+  if(complete_buddy) 
     {
       while((temp_buddy = (yahoo_account *) get_nth_buddy (buddy_index)))
 	{
@@ -366,26 +369,26 @@ command_generator (const char *text, int state)
 	  name = temp_buddy->yahoo_id;
 	  if (!name || (name[0] == 0))
 	    continue;
-
+	  
 	  if (strncasecmp (name, text, len) == 0)
 	    return strdup (name);
 	}
     }
-
-    if ( complete_conf)
+  
+  if ( complete_conf)
     {
-       /* conf rooms */
-       while(conflist) 
-       {
-         rooms = (conf_room *)conflist->data;
-         conflist = conflist->next;
-         if(rooms && rooms->room_name && 
+      /* conf rooms */
+      while(conflist) 
+	{
+	  rooms = (conf_room *)conflist->data;
+	  conflist = conflist->next;
+	  if(rooms && rooms->room_name && 
              !strncasecmp(rooms->room_name,text,len))
             return strdup(rooms->room_name);
-       }
+	}
     }
-
-    if (complete_toggle)
+  
+  if (complete_toggle)
     {
       switch (toggle_index)
 	{
@@ -411,43 +414,43 @@ command_generator (const char *text, int state)
 	}
     }
 
-    if(complete_cmd) {
-       if (gh_list_p (dynamic_commands))
-       {
-          dynamic_commands_count = gh_length (dynamic_commands);
-          while (dynamic_cmd_index < dynamic_commands_count)
-          {
-	  dynamic_command = 
-	    gh_scm2newstr (gh_list_ref (gh_list_ref (dynamic_commands, 
-					gh_ulong2scm (dynamic_cmd_index++)),
-					gh_ulong2scm (0)),
-			   NULL);
-	  if (dynamic_command && strncasecmp (dynamic_command, text, len) == 0)
-	    return strdup (dynamic_command);
-	}
+  if(complete_cmd) {
+    if (gh_list_p (dynamic_commands))
+      {
+	dynamic_commands_count = gh_length (dynamic_commands);
+	while (dynamic_cmd_index < dynamic_commands_count)
+	  {
+	    dynamic_command = 
+	      gh_scm2newstr (gh_list_ref (gh_list_ref (dynamic_commands, 
+						       gh_ulong2scm (dynamic_cmd_index++)),
+					  gh_ulong2scm (0)),
+			     NULL);
+	    if (dynamic_command && strncasecmp (dynamic_command, text, len) == 0)
+	      return strdup (dynamic_command);
+	  }
       }
-  
-      // for normal command
-      while ((name = commands[i]))
-        {
-          i++;
-          if (strncasecmp (name, text, len) == 0)
-	   return (char *) strdup (name);
-        }
-    }
-
-    if (complete_dict)
+      
+    // for normal command
+    while ((name = commands[i]))
+      {
+	i++;
+	if (strncasecmp (name, text, len) == 0)
+	  return (char *) strdup (name);
+      }
+  }
+    
+  if (complete_dict)
     {
-	if (dw && !strncmp(dw->word, text, strlen(text))) {
-            char *ret = dw->word;
-            dw = dw->next;
-	    return strdup(ret);
-	} else {
-            dw = NULL;
-	}
+      if (dw && !strncmp(dw->word, text, strlen(text))) {
+	char *ret = dw->word;
+	dw = dw->next;
+	return strdup(ret);
+      } else {
+	dw = NULL;
+      }
     }
   
-    return (char *) NULL; /* in the end */
+  return (char *) NULL; /* in the end */
 }
 
 char **
@@ -473,7 +476,7 @@ complete_text (char *text, int start, int end)
 void
 syntax_error (void)
 {
-  printf ("syntax error: type \"?help [command]\" for more info\n");
+  printf ("syntax error: type \"/help [command]\" for more info\n");
 }
 
 void
@@ -495,8 +498,8 @@ interpreter (char *line)
   if (strlen (line) == 0)
     {
       /* AUTO-INSERT MODE and READLINE handling is kind of hack in
-      Freehoo. But it works great. If you cannot follow the source
-      code, please ask Anand Avati or Bala or Anand Babu */
+	 Freehoo. But it works great. If you cannot follow the source
+	 code, please ask Anand Avati or Bala or Anand Babu */
 
       current_target_buddy_mode_t mode;
       static int recv_new;
@@ -517,29 +520,29 @@ interpreter (char *line)
   command = get_token (&line);
   
   /*  if (line)
-         line = stripwhite (line);
+      line = stripwhite (line);
   */
   
-  if (strcasecmp (command, "?quit") == 0)
+  if (strcasecmp (command, "/quit") == 0)
     {
       set_quit_flag (1);
       return;
     }
   
-  if (strcasecmp (command, "?help") == 0)
+  if (strcasecmp (command, "/help") == 0)
     {
       // help arguments are optional
       command_show_help (line);
       return;
     }
   
-  if (strcasecmp (command, "?status") == 0)
+  if (strcasecmp (command, "/status") == 0)
     {
       command_status (line);
       return;
     }
   
-  if (strcasecmp (command, "?refresh") == 0)
+  if (strcasecmp (command, "/refresh") == 0)
     {
       YList *buds, *igns;
 
@@ -554,7 +557,7 @@ interpreter (char *line)
       return;
     }
 
-  if (strcasecmp (command, "?add") == 0)
+  if (strcasecmp (command, "/add") == 0)
     {
       if (line && *line)
 	command_buddy_add (line);
@@ -563,7 +566,7 @@ interpreter (char *line)
       return;
     }
   
-  if (strcasecmp (command, "?remove") == 0)
+  if (strcasecmp (command, "/remove") == 0)
     {
       if (line && *line)
 	command_buddy_remove (line);
@@ -572,7 +575,7 @@ interpreter (char *line)
       return;
     }
 
-  if (strcasecmp (command, "?conf-start") == 0)
+  if (strcasecmp (command, "/conf-start") == 0)
     {
       if (line && *line)
 	command_conf_begin (line);
@@ -581,7 +584,7 @@ interpreter (char *line)
       return;
     }
 
-  if (strcasecmp (command, "?conf-add") == 0)
+  if (strcasecmp (command, "/conf-add") == 0)
     {
       if (line && *line)
 	command_conf_add (line);
@@ -589,7 +592,7 @@ interpreter (char *line)
 	syntax_error ();
       return;
     }
-  if (strcasecmp (command, "?conf-join") == 0)
+  if (strcasecmp (command, "/conf-join") == 0)
     {
       if (line && *line)
 	command_conf_join (line);
@@ -597,7 +600,7 @@ interpreter (char *line)
 	syntax_error ();
       return;
     }
-  if (strcasecmp (command, "?conf-decline") == 0)
+  if (strcasecmp (command, "/conf-decline") == 0)
     {
       if (line && *line)
 	command_conf_decline (line);
@@ -605,7 +608,7 @@ interpreter (char *line)
 	syntax_error ();
       return;
     }
-  if (strcasecmp (command, "?conf-end") == 0)
+  if (strcasecmp (command, "/conf-end") == 0)
     {
       if (line && *line)
 	command_conf_quit (line);
@@ -613,12 +616,12 @@ interpreter (char *line)
 	syntax_error ();
       return;
     }
-  if (strcasecmp (command, "?conf-list") == 0)
+  if (strcasecmp (command, "/conf-list") == 0)
     {
       command_conf_list (line);
       return;
     }
-  if (strcasecmp (command, "?conf-send") == 0)
+  if (strcasecmp (command, "/conf-send") == 0)
     {
       if (line && *line)
 	command_conf_send (line);
@@ -627,7 +630,7 @@ interpreter (char *line)
       return;
     }
 
-  if (strcasecmp (command, "?reject") == 0)
+  if (strcasecmp (command, "/reject") == 0)
     {
       if (line && *line)
 	command_buddy_reject (line);
@@ -636,7 +639,7 @@ interpreter (char *line)
       return;
     }
 
-  if (strcasecmp (command, "?ignore") == 0)
+  if (strcasecmp (command, "/ignore") == 0)
     {
       if (line && *line)
 	command_buddy_ignore (line);
@@ -645,7 +648,7 @@ interpreter (char *line)
       return;
     }
 
-  if (strcasecmp (command, "?unignore") == 0)
+  if (strcasecmp (command, "/unignore") == 0)
     {
       if (line && *line)
 	command_buddy_unignore (line);
@@ -654,19 +657,19 @@ interpreter (char *line)
       return;
     }
 
-  if (strcasecmp (command, "?who") == 0)
+  if (strcasecmp (command, "/who") == 0)
     {
       display_buddy_list ();
       return;
     }
 
-  if (strcasecmp (command, "?ignorelist") == 0)
+  if (strcasecmp (command, "/ignorelist") == 0)
     {
       display_ignore_list ();
       return;
     }
 
-  if (strcasecmp (command, "?send") == 0)
+  if (strcasecmp (command, "/send") == 0)
     {
       if (line && *line)
 	command_send_message (line);
@@ -675,7 +678,7 @@ interpreter (char *line)
       return;
     }
 
-  if (strcasecmp (command, "?send-file") == 0)
+  if (strcasecmp (command, "/send-file") == 0)
     {
       if (line && *line)
 	command_send_file (line);
@@ -684,7 +687,7 @@ interpreter (char *line)
       return;
     }
   
-  if (strcasecmp (command, "?eval") == 0)
+  if (strcasecmp (command, "/eval") == 0)
     {
       if (line && *line)
 	command_eval_scheme_str (line);
@@ -693,7 +696,7 @@ interpreter (char *line)
       return;
     }
   
-  if (strcasecmp (command, "?load") == 0)
+  if (strcasecmp (command, "/load") == 0)
     {
       if (line && *line)
 	command_load_scheme_file (line);
@@ -702,7 +705,7 @@ interpreter (char *line)
       return;
     }
   
-  if (strcasecmp (command, "?toggle") == 0)
+  if (strcasecmp (command, "/toggle") == 0)
     {
       if (line && *line)
 	command_toggle (line);
@@ -711,7 +714,7 @@ interpreter (char *line)
       return;
     }
   
-  if (strcasecmp (command, "?bell") == 0)
+  if (strcasecmp (command, "/bell") == 0)
     {
       command_bell ();
       return;
@@ -735,7 +738,7 @@ interpreter (char *line)
   
    
   /* you can add your new command like this
-     if (strcasecmp (command, "?my_command") == 0)
+     if (strcasecmp (command, "/my_command") == 0)
      {
      if (line && *line)
      {
@@ -750,10 +753,11 @@ interpreter (char *line)
   */
   
   //default handler
-  if (line && *line)
+  if (line && *line) {
     command_default_handler (command, line);
-  //else
-  //  syntax_error ();
+  } else {
+    set_current_target_buddy( command, current_target_buddy_mode_send);
+  }
   
   return;
 }
@@ -770,90 +774,90 @@ command_show_help (char *line)
     all = 1;
   
 
-  if (all || (strcasecmp (command, "?send") == 0))
+  if (all || (strcasecmp (command, "/send") == 0))
     {
-      printf ("?send BUDDY MESSAGE\n"
+      printf ("/send BUDDY MESSAGE\n"
 	      "\t- send MESSAGE to BUDDY\n");
     }
-  if (all || (strcasecmp (command, "?send-file") == 0))
+  if (all || (strcasecmp (command, "/send-file") == 0))
     {
-      printf ("?send-file BUDDY filepath [MESSAGE...]\n"
+      printf ("/send-file BUDDY filepath [MESSAGE...]\n"
 	      "\t- send a file to BUDDY with a MSG\n");
     }
-  if (all || (strcasecmp (command, "?who") == 0))
+  if (all || (strcasecmp (command, "/who") == 0))
     {
-      printf ("?who\n"
+      printf ("/who\n"
 	      "\t- display buddy list as well as online or offline\n");
     }
-  if (all || (strcasecmp (command, "?ignore") == 0))
+  if (all || (strcasecmp (command, "/ignore") == 0))
     {
-      printf ("?ignore BUDDY\n"
+      printf ("/ignore BUDDY\n"
 	      "\t- ignore messages from this BUDDY\n");
     }
-  if (all || (strcasecmp (command, "?unignore") == 0))
+  if (all || (strcasecmp (command, "/unignore") == 0))
     {
-      printf ("?unignore BUDDY\n"
+      printf ("/unignore BUDDY\n"
 	      "\t- unignore a BUDDY\n");
     }
-  if (all || (strcasecmp (command, "?ignore-list") == 0))
+  if (all || (strcasecmp (command, "/ignore-list") == 0))
     {
-      printf ("?ignore-list\n"
+      printf ("/ignore-list\n"
 	      "\t- display ignore list\n");
     }
-  if (all || (strcasecmp (command, "?add") == 0))
+  if (all || (strcasecmp (command, "/add") == 0))
     {
-      printf ("?add BUDDY [GROUP] [MESSAGE...]\n"
+      printf ("/add BUDDY [GROUP] [MESSAGE...]\n"
 	      "\t- add BUDDY to GROUP and send him this MESSAGE\n");
     }
-  if (all || (strcasecmp (command, "?remove") == 0))
+  if (all || (strcasecmp (command, "/remove") == 0))
     {
-      printf ("?remove BUDDY\n"
+      printf ("/remove BUDDY\n"
 	      "\t- remove BUDDY from friends list\n");
     }
-  if (all || (strcasecmp (command, "?conf-start") == 0))
+  if (all || (strcasecmp (command, "/conf-start") == 0))
     {
-      printf ("?conf-start ROOM [BUDDYLIST]\n"
+      printf ("/conf-start ROOM [BUDDYLIST]\n"
 	      "\t- start conference ROOM and invite buddies\n");
     }
-  if (all || (strcasecmp (command, "?conf-add") == 0))
+  if (all || (strcasecmp (command, "/conf-add") == 0))
     {
-      printf ("?conf-add ROOM BUDDY\n"
+      printf ("/conf-add ROOM BUDDY\n"
 	      "\t- add a BUDDY to existing conference ROOM\n");
     }
-  if (all || (strcasecmp (command, "?conf-join") == 0))
+  if (all || (strcasecmp (command, "/conf-join") == 0))
     {
-      printf ("?conf-join ROOM\n"
+      printf ("/conf-join ROOM\n"
 	      "\t- Join a conference ROOM as invited by a buddy\n");
     }
-  if (all || (strcasecmp (command, "?conf-decline") == 0))
+  if (all || (strcasecmp (command, "/conf-decline") == 0))
     {
-      printf ("?conf-decline room\n"
+      printf ("/conf-decline room\n"
 	      "\t- Decline to a conf room as invited by a buddy\n");
     }
-  if (all || (strcasecmp (command, "?conf-end") == 0))
+  if (all || (strcasecmp (command, "/conf-end") == 0))
     {
-      printf ("?conf-end ROOM\n"
+      printf ("/conf-end ROOM\n"
 	      "\t- Quit from a conference ROOM\n");
     }
-  if (all || (strcasecmp (command, "?conf-list") == 0))
+  if (all || (strcasecmp (command, "/conf-list") == 0))
     {
-      printf ("?conf-list\n"
+      printf ("/conf-list\n"
 	      "\t- View list of conference rooms\n");
     }
-  if (all || (strcasecmp (command, "?conf-send") == 0))
+  if (all || (strcasecmp (command, "/conf-send") == 0))
     {
-      printf ("?conf-send ROOM MESSAGE\n"
+      printf ("/conf-send ROOM MESSAGE\n"
 	      "\t- send MESSAGE to conference ROOM\n");
     }
 
-  if (all || (strcasecmp (command, "?reject") == 0))
+  if (all || (strcasecmp (command, "/reject") == 0))
     {
-      printf ("?reject BUDDY [MESSAGE]\n"
+      printf ("/reject BUDDY [MESSAGE]\n"
 	      "\t- reject BUDDY for adding you in his/her buddy list\n");
     }
-  if (all || (strcasecmp (command, "?status") == 0))
+  if (all || (strcasecmp (command, "/status") == 0))
     {
-      printf ("?status [STATUS] [CUSTOM-MESSAGE...]\n"
+      printf ("/status [STATUS] [CUSTOM-MESSAGE...]\n"
 	      "\t- set or view STATUS information\n");
       if (!all)
 	{
@@ -867,24 +871,24 @@ command_show_help (char *line)
 	    }
 	}
     }
-  if (all || (strcasecmp (command, "?refresh") == 0))
+  if (all || (strcasecmp (command, "/refresh") == 0))
     {
-      printf ("?refresh\n"
+      printf ("/refresh\n"
 	      "\t- refresh userlist and status information\n");
     }
-  if (all || (strcasecmp (command, "?eval") == 0))
+  if (all || (strcasecmp (command, "/eval") == 0))
     {
-      printf ("?eval SCHEME-CODE\n"
+      printf ("/eval SCHEME-CODE\n"
 	      "\t- evaluates the SCHEME-CODE\n");
     }
-  if (all || (strcasecmp (command, "?load") == 0))
+  if (all || (strcasecmp (command, "/load") == 0))
     {
-      printf ("?load SCHEME-FILE\n"
+      printf ("/load SCHEME-FILE\n"
 	      "\t- loads and evaluates the SCHEME-FILE\n");
     }
-  if (all || (strcasecmp (command, "?toggle") == 0))
+  if (all || (strcasecmp (command, "/toggle") == 0))
     {
-      printf ("?toggle VARIABLE\n"
+      printf ("/toggle VARIABLE\n"
 	      "\t- toggles the state of VARIABLE to ON and OFF\n"
 	      "\tVariables:\n"
 	      "\t\tbell    - OFF / ON\n"
@@ -892,25 +896,25 @@ command_show_help (char *line)
 	      "\t\tsession - VANILLA / AUTO-INSERT\n"
 	      "\t\tstatus  - Buddy status notifications HIDE / SHOW\n");
     }
-  if (all || (strcasecmp (command, "?bell") == 0))
+  if (all || (strcasecmp (command, "/bell") == 0))
     {
-      printf ("?bell\n"
+      printf ("/bell\n"
 	      "\t- toggles the bell ON and OFF\n");
     }
-  if (all || (strcasecmp (command, "?quit") == 0))
+  if (all || (strcasecmp (command, "/quit") == 0))
     {
-      printf ("?quit\n"
+      printf ("/quit\n"
 	      "\t- logout of messenger and quit\n");
     }
-  if (all || (strcasecmp (command, "?help") == 0))
+  if (all || (strcasecmp (command, "/help") == 0))
     {
-      printf ("?help [COMMAND]\n"
+      printf ("/help [COMMAND]\n"
 	      "\t- display elaborate help on this COMMAND\n");
     }
   /* adds help facility to your new command
-     if (all || (strcasecmp (command, "?my_command") == 0))
+     if (all || (strcasecmp (command, "/my_command") == 0))
      {
-     printf("?my_command [optional argument]\n"
+     printf("/my_command [optional argument]\n"
      "\t- my_command really freaks ;-)\n");
      }
   */
@@ -927,7 +931,7 @@ command_show_help (char *line)
 	    gh_list_ref (dynamic_commands, gh_ulong2scm (i));
 	  dynamic_command = 
 	    gh_scm2newstr (gh_list_ref (tmp_scm, gh_ulong2scm (0)),
-					   NULL);
+			   NULL);
 	  if (all || (strcasecmp (command, dynamic_command) == 0))
 	    {
 	      dynamic_syntax = 
@@ -961,7 +965,7 @@ command_status (char *line)
   
   if (!sscanf (current_status_str, "%d", &current_status))
     {
-      fprintf (stderr, "Invalid status number, Type \"?help ?status\""
+      fprintf (stderr, "Invalid status number, Type \"/help /status\""
 	       "for more info\n");
       return;
     }
@@ -971,7 +975,7 @@ command_status (char *line)
   else 
     {
       printf ("Unknown status code [%d]\n"
-	      "Type \"?help ?status\" for more info\n",
+	      "Type \"/help /status\" for more info\n",
 	      current_status);
       return;
     }
@@ -982,16 +986,16 @@ command_status (char *line)
       if (!current_status_msg)
 	{
 	  printf ("Missing custom message, "
-		  "type \"?help ?status\" for proper syntax\n");
+		  "type \"/help /status\" for proper syntax\n");
 	  return;
 	}
-	yahoo_set_away (get_fh_session ()->id,
-			current_status, 
-			current_status_msg,
-			1);
-	printf ("[%s] changing status to [%s]\n", 
-		get_default_login_id (),
-		current_status_msg);
+      yahoo_set_away (get_fh_session ()->id,
+		      current_status, 
+		      current_status_msg,
+		      1);
+      printf ("[%s] changing status to [%s]\n", 
+	      get_default_login_id (),
+	      current_status_msg);
 
     }
   else
@@ -1000,9 +1004,9 @@ command_status (char *line)
 		      current_status,
 		      NULL,
 		      1);
-	printf ("[%s] changing status to [%s]\n", 
-		get_default_login_id (),
-		yahoo_status_code (get_current_status ()));
+      printf ("[%s] changing status to [%s]\n", 
+	      get_default_login_id (),
+	      yahoo_status_code (get_current_status ()));
     }
 }
 
@@ -1055,10 +1059,10 @@ command_buddy_add (char *line)
     FIXME: Visu, Aug 23, 2004:
     ==========================
     1. The following function prototype is changed from previous
-       libyahoo2 versions.
+    libyahoo2 versions.
     2. The changes is the extra parameter (char *) at the end, For
-       now, NULL string is passed, with which its working fine. This
-       needs a revisit and approprite string to be passed if required.
+    now, NULL string is passed, with which its working fine. This
+    needs a revisit and approprite string to be passed if required.
   */
   yahoo_add_buddy (get_fh_session ()->id, user_id, 
 		   ((group == NULL) ? FH_DEFAULT_GROUP : group), "");
@@ -1182,7 +1186,7 @@ command_toggle (char *line)
   if (toggle_arg == (char *) NULL)
     {
       fprintf (stderr,
-	       "Invalid argument to \"?toggle\", see \"?help ?toggle\""
+	       "Invalid argument to \"/toggle\", see \"/help /toggle\""
 	       "for more info\n");
       return;
     }
@@ -1265,7 +1269,7 @@ void
 command_dynamic_commands (char *dynamic_command, char *line)
 {
   /*
-    (and (defined? '?command) (?command '(arg1 arg2 art3 ...)))
+    (and (defined? '?command) (/command '(arg1 arg2 art3 ...)))
   */
   char *dynamic_command_line;
   int length;
@@ -1285,8 +1289,8 @@ command_dynamic_commands (char *dynamic_command, char *line)
 
   /* Using sprintf is dangerous, because dynamic_command field and
      line field are supplied by the user. Commented by ab
-  sprintf (dynamic_command_line, "(and (defined? '%s) (%s '(%s)))", 
-	   dynamic_command, dynamic_command, line);
+     sprintf (dynamic_command_line, "(and (defined? '%s) (%s '(%s)))", 
+     dynamic_command, dynamic_command, line);
   */
 
   strcpy (dynamic_command_line, "(and (defined? '");
@@ -1366,7 +1370,7 @@ command_conf_add (char *line)
   
   cr->members = y_list_append (cr->members, strdup(member));
   yahoo_conference_addinvite (get_fh_session ()->id,
-			     NULL, member, room, cr->members, "Join my conference");
+			      NULL, member, room, cr->members, "Join my conference");
 }
 
 void 
@@ -1402,7 +1406,7 @@ command_conf_begin (char *line)
   conferences = y_list_append (conferences, cr);
   cr->members = y_list_append (cr->members, strdup (get_fh_session ()->yahoo_id));
   yahoo_conference_invite (get_fh_session ()->id, NULL,
-			  cr->members, cr->room_name, "Join my conference");
+			   cr->members, cr->room_name, "Join my conference");
   // AUTO-INSERT-MODE
   set_current_target_buddy (cr->room_name,current_target_buddy_mode_send);
 }
@@ -1455,7 +1459,7 @@ command_conf_decline (char *line)
     }
 
   yahoo_conference_decline (get_fh_session ()->id,
-			   NULL, cr->members, room,msg);
+			    NULL, cr->members, room,msg);
 
   conferences = y_list_remove(conferences, cr);
   free(cr->room_name);
@@ -1498,7 +1502,7 @@ command_conf_join (char *line)
     cr->members = y_list_append (cr->members,
 				 strdup (get_fh_session ()->yahoo_id));
   yahoo_conference_logon (get_fh_session ()->id, NULL,
-			 cr->members, room);
+			  cr->members, room);
   // AUTO-INSERT-MODE
   set_current_target_buddy (room,current_target_buddy_mode_send);
 }
@@ -1614,12 +1618,12 @@ command_send_file (char *line)
    * current state (open fd and fsize)
    */
   yahoo_send_file((get_fh_session ())->id, user_id, msg,
-		       filename, fsize, send_file_getfd_callback,
-                       (void *)&data);
+		  filename, fsize, send_file_getfd_callback,
+		  (void *)&data);
 }
 
 char *
 complete_none (const char *text,int state)
 {
-    return (char *)NULL;
+  return (char *)NULL;
 }
